@@ -6,38 +6,44 @@ import json
 class igdb:
 
     __api_key = ""
+    __args = ""
     __api_url = "https://api-2445582011268.apicast.io/"
 
     def __init__(self,api_key):
         self.__api_key = api_key
 
+    #CREATE URL FROM PARAMETERS
+    def joinParameters(self,parameter="",types="",default="",prefix=""):
+        if parameter in self.__args:
+            default = str(prefix)
+            if type(self.__args[parameter]) != types:
+                default += ",".join(map(str,self.__args[parameter]))
+            else:
+                default += str(self.__args[parameter])
+        return default
+
     #CALL TO THE API
     def call_api(self,endpoint,args):
-        ids     = ""
+        ids=order=filters=expand=limit=offset = ""
         fields  = "*"
-        order   = ""
-        filters = ""
-        #If array, convert it to komma seperated string
+        self.__args=args
+
+        #If dict, convert it to komma seperated string
         if type(args) != int:
-            if 'ids' in args:
-                if type(args['ids']) != int:
-                    ids = ",".join(map(str,args['ids']))
-                else:
-                    ids = args['ids']
-            if 'fields' in args:
-                if type(args['fields']) != str:
-                    fields = ",".join(map(str,args['fields']))
-                else:
-                    fields = args['fields']
-            if 'order' in args:
-                order = "&order=" + str(args['order'])
+            ids     = self.joinParameters(parameter='ids',types=int)
+            fields  = self.joinParameters(parameter='fields',types=str,default="*")
+            expand  = self.joinParameters(parameter='expand',types=str,prefix="&expand=")
+            limit   = self.joinParameters(parameter='limit',types=int,prefix="&limit=")
+            offset  = self.joinParameters(parameter='offset',types=int,prefix="&offset=")
+            order   = self.joinParameters(parameter='order',types=str,prefix="&order=")
+
             if 'filters' in args:
                 for key, value in args['filters'].items():
-                    filters = filters + "&filter" + key + "=" + str(value)
+                    filters += "&filter" + key + "=" + str(value)
         else:
             ids = args
 
-        url = self.__api_url + endpoint + "/" + str(ids) + "?fields=" + str(fields)+ str(filters)+ str(order)
+        url = self.__api_url + endpoint + "/" + str(ids) + "?fields=" + str(fields)+ str(filters)+ str(order)+ str(limit)+ str(offset)+ str(expand)
         print(url)
 
         headers = {
@@ -45,7 +51,6 @@ class igdb:
             'Accept' : 'application/json'
             }
         r = requests.get(url, headers=headers)
-
         return r
 
     #GAMES
